@@ -177,7 +177,7 @@ class Cmd_Track_Obj(CmdContext_Track):
     match = r"object (?P<obj>.+)"
 
     def parse(self, cfg, obj):
-        deepsetdefault(cfg, "object", last=set()).add(obj)
+        deepsetdefault(cfg, "object", last=set()).add(int(obj))
 
 
 
