@@ -823,6 +823,16 @@ class Cvt_Int_SwPortTrkAlw(DiffConvert_Int):
 # ...
 
 
+class Cvt_Int_PcMinLinks(DiffConvert_Int):
+    cmd = "port-channel-min-links",
+
+    def remove(self, old, int_name):
+        return self.enter(int_name) + [" no port-channel min-links"]
+
+    def update(self, old, upd, new, int_name):
+        return self.enter(int_name) + [" port-channel min-links " + str(new)]
+
+
 class Cvt_Int_XConn(DiffConvert_Int):
     cmd = "xconnect",
 
